## Requirements

- Generate synthetic data
- View attention maps
- Use torch 2x
- Train inside docker compose with cuda
- Build as package
- Deploy on hugging face
- Automated network testing
- Use lighting, accelerator, tqdm
- Use wandb
- Build the model with pytorch models
- Parameter search (ray tune)
- View easily
- Use mkdocs in black
- Use rerun
